aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAlexis La Goutte <alexis.lagoutte@gmail.com>2016-10-27 18:01:53 +0200
committerAnders Broman <a.broman58@gmail.com>2016-10-28 07:36:03 +0000
commit236f25dfac16755715768c449fcd3b3ebb7175fd (patch)
tree3184a5d4fa470d02fe32771516658f9fc8d28c17
parent120e515bf00fd8f545c9584be997c7b966c5b5c7 (diff)
RADIUS: fix fix spelling typo found by lintian
Change-Id: Iea8c96064c39d0e4aee5db6c72a8c120c56e495e Reviewed-on: https://code.wireshark.org/review/18531 Reviewed-by: Anders Broman <a.broman58@gmail.com>
-rw-r--r--epan/dissectors/packet-radius.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-radius.c b/epan/dissectors/packet-radius.c
index 0352a9b12b..6d81f7bfc6 100644
--- a/epan/dissectors/packet-radius.c
+++ b/epan/dissectors/packet-radius.c
@@ -1763,7 +1763,7 @@ is_radius(tvbuff_t *tvb)
/*
* returns true if the response authenticator is valid
* input: tvb of the reponse, corresponding request authenticator
* uses the shared secret to calculate the Response authenticator
* and checks with the current.
* see RFC 2865, packet format page 16
@@ -2637,7 +2637,7 @@ proto_register_radius(void)
prefs_register_string_preference(radius_module, "shared_secret", "Shared Secret",
"Shared secret used to decode User Passwords and validate Response Authenticators",
&shared_secret);
- prefs_register_bool_preference(radius_module, "validate_authenticator", "Validate Reponse Authenticator",
+ prefs_register_bool_preference(radius_module, "validate_authenticator", "Validate Response Authenticator",
"Whether to check or not if Response Authenticator is correct. You need to define shared secret for this to work.",
&validate_authenticator);
prefs_register_bool_preference(radius_module, "show_length", "Show AVP Lengths",
@@ -1763,7 +1763,7 @@ is_radius(tvbuff_t *tvb)
/*
* returns true if the response authenticator is valid
- * input: tvb of the reponse, corresponding request authenticator
+ * input: tvb of the response, corresponding request authenticator
* uses the shared secret to calculate the Response authenticator
* and checks with the current.